#
# Conditional build:
%bcond_without	static_libs	# static library

Summary:	C library for the Publix Suffix List
Summary(pl.UTF-8):	Biblioteka C do obsługi listy przyrostków publicznych (Public Suffix List)
Name:		libpsl
Version:	0.14.0
Release:	1
License:	MIT
Group:		Networking
#Source0Download: https://github.com/rockdaboot/libpsl/releases
Source0:	https://github.com/rockdaboot/libpsl/releases/download/%{name}-%{version}/%{name}-%{version}.tar.gz
# Source0-md5:	ace83b37a37d94fa2dd543ccda80138b
%if 0
# not required if packaged with libpsl release
%define	psl_ref	1fc1ed365818a6a77d6f31d425ff03ca54cdc7f3
%define	psldate	20150827
Source1:	https://github.com/publicsuffix/list/archive/%{psl_ref}/publicsuffix_list-%{psldate}.tar.gz
# Source1-md5:	ee9a591d4545d9f6ca350bd9df2c2e51
%endif
Patch0:		%{name}-am.patch
URL:		https://rockdaboot.github.io/libpsl
BuildRequires:	autoconf >= 2.59
BuildRequires:	automake >= 1:1.10
BuildRequires:	gettext-tools >= 0.18.1
BuildRequires:	glib2-devel
BuildRequires:	gtk-doc >= 1.15
BuildRequires:	libicu-devel
BuildRequires:	libtool >= 2:2
BuildRequires:	libxslt-progs
BuildRequires:	pkgconfig
BuildRequires:	python >= 1:2.7
BuildRequires:	sed >= 4.0
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
libpsl is a C library to handle the Public Suffix List. A "public
suffix" is a domain name under which Internet users can directly
register own names.

Browsers and other web clients can use it to
- Avoid privacy-leaking "supercookies";
- Avoid privacy-leaking "super domain" certificates;
- Domain highlighting parts of the domain in a user interface;
- Sorting domain lists by site;

Libpsl...
- has built-in PSL data for fast access;
- allows to load PSL data from files;
- checks if a given domain is a "public suffix";
- provides immediate cookie domain verification;
- finds the longest public part of a given domain;
- finds the shortest private part of a given domain;
- works with international domains (UTF-8 and IDNA2008 Punycode);
- is thread-safe;
- handles IDNA2008 UTS#46;

%description -l pl.UTF-8
libpsl to biblioteka C do obsługi listy przyrostków publicznych
(Public Suffix List). "Przyrostek publiczny" to nazwa domeny, poniżej
której bezpośrednio użytkownicy Internetu mogą rejestrować własne
nazwy.

Przeglądarki i inni klienci WWW mogą jej używać w celu:
- zapobieganiu "superciasteczek" naruszającym prywatność
- zapobieganiu certyfikatom "superdomenowym" naruszającym prywatność
- podświetlania części domen w interfejsie użytkownika
- sortowania listy domen według serwisu.

Libpsl:
- ma wbudowane dane PSL dla szybkiego dostępu
- pozwala na wczytywanie danych PSL z plików
- sprawdza, czy dana domena jest "przyrostkiem publicznym"
- zapewnia natychmiastową weryfikację domeny ciasteczka
- znajduje najdłuższą publiczną część podanej domeny
- znajduje najkrótszą prywatną część podanej domeny
- działa z domenami międzynarodowymi (UTF-8 i IDNA2008 Punycode)
- jest bezpieczna względem wątków
- obsługuje IDNA2008 UTS#46.

%package devel
Summary:	Development files for libpsl
Summary(pl.UTF-8):	Pliki programistyczne biblioteki libpsl
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}

%description devel
This package contains the header file for developing applications that
use libpsl.

%description devel -l pl.UTF-8
Ten pakiet zawiera plik nagłówkowy do tworzenia aplikacji
wykorzystujących bibliotekę libpsl.

%package static
Summary:	Static libpsl library
Summary(pl.UTF-8):	Statyczna biblioteka libpsl
Group:		Development/Libraries
Requires:	%{name}-devel = %{version}-%{release}

%description static
Static libpsl library.

%description static -l pl.UTF-8
Statyczna biblioteka libpsl.

%package apidocs
Summary:	API documentation for libpsl library
Summary(pl.UTF-8):	Dokumentacja API biblioteki libpsl
Group:		Documentation
%if "%{_rpmversion}" >= "5"
BuildArch:	noarch
%endif

%description apidocs
API documentation for libpsl library.

%description apidocs -l pl.UTF-8
Dokumentacja API biblioteki libpsl.

%package utils
Summary:	Commandline utility to explore the Public Suffix List
Summary(pl.UTF-8):	Narzędzie linii poleceń do eksplorowania listy przyrostków publicznych
Group:		Applications/Networking
Requires:	%{name} = %{version}-%{release}

%description utils
This package contains a commandline utility to explore the Public
Suffix List, for example it checks if domains are public suffixes,
checks if cookie-domain is acceptable for domains and so on.

%description utils -l pl.UTF-8
Ten pakiet zawiera narzędzie linii poleceń do eksplorowania listy
przyrostków publicznych (Public Suffix List); sprawdza ono na
przykład, czy domeny są przyrostkami publicznymi, czy domena
ciasteczka jest akceptowalna dla domen itp.

%prep
%setup -q
%patch0 -p1

%if 0
rmdir list
%{__tar} xf %{SOURCE1}
%{__mv} list-%{psl_ref} list
%endif

%build
%{__gettextize}
%{__gtkdocize}
%{__libtoolize}
%{__aclocal} -I m4
%{__autoconf}
%{__autoheader}
%{__automake}

%configure \
	--disable-silent-rules \
	%{!?with_static_libs:--disable-static} \
	--enable-gtk-doc \
	--enable-man \
	--with-html-dir=%{_gtkdocdir}

%{__make}

%{?with_tests:%{__make} check}

%install
rm -rf $RPM_BUILD_ROOT
%{__make} install \
	DESTDIR=$RPM_BUILD_ROOT

# obsoleted by pkg-config
%{__rm} $RPM_BUILD_ROOT%{_libdir}/libpsl.la

%clean
rm -rf $RPM_BUILD_ROOT

%post	-p /sbin/ldconfig
%postun	-p /sbin/ldconfig

%files
%defattr(644,root,root,755)
%doc AUTHORS COPYING NEWS
%attr(755,root,root) %{_libdir}/libpsl.so.*.*.*
%attr(755,root,root) %ghost %{_libdir}/libpsl.so.5

%files devel
%defattr(644,root,root,755)
%attr(755,root,root) %{_libdir}/libpsl.so
%{_includedir}/libpsl.h
%{_pkgconfigdir}/libpsl.pc
%{_mandir}/man3/libpsl.3*

%files static
%defattr(644,root,root,755)
%{_libdir}/libpsl.a

%files apidocs
%defattr(644,root,root,755)
%{_gtkdocdir}/libpsl

%files utils
%defattr(644,root,root,755)
%attr(755,root,root) %{_bindir}/psl
%changelog
* Tue Aug 30 2016 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/libpsl.git;a=log;h=master

* Tue Aug 30 2016 Jakub Bogusz <qboosh@pld-linux.org> db5e5d2
- updated to 0.14.0

* Sat May 21 2016 Jakub Bogusz <qboosh@pld-linux.org> 4585954
- updated to 0.13.0 (note: new soname)

* Sun May 15 2016 Elan Ruusamäe <glen@delfi.ee> 2591e98
- icu-57.1 rebuild
- release 4 (by relup.sh)

* Sun May 15 2016 Elan Ruusamäe <glen@delfi.ee> 623ec94
- icu-57.1 rebuild
- release 3 (by relup.sh)

* Fri Apr 29 2016 Elan Ruusamäe <glen@delfi.ee> abef6c1
- noarch apidocs

* Wed Nov 25 2015 Jakub Bogusz <qboosh@pld-linux.org> 64042f0
- updated to 0.11.0

* Wed Nov 18 2015 Jan Rękorajski <baggins@pld-linux.org> 28ccc78
- release 2 (by relup.sh)

* Sun Sep 06 2015 Jakub Bogusz <qboosh@pld-linux.org> b6d6f74
- updated to 0.8.1, publicsuffix list from 20150827
- updated am patch

* Mon Jun 08 2015 Elan Ruusamäe <glen@delfi.ee> 0adba9e
- icu rebuild
- release 2 (by relup.sh)

* Mon Mar 02 2015 Jakub Bogusz <qboosh@pld-linux.org> 159d56f
- updated to 0.7.1
- added am patch (automake rebuild fix)

* Tue Feb 24 2015 Jan Rękorajski <baggins@pld-linux.org> 19de211
- x32 rebuild
- release 2 (by relup.sh)

* Wed Dec 31 2014 Jan Rękorajski <baggins@pld-linux.org> b3607a9
- updated gettext BR

* Fri Oct 31 2014 Jakub Bogusz <qboosh@pld-linux.org> 421caf1
- updated to 0.6.0, finished packaging

* Fri Oct 31 2014 Jakub Bogusz <qboosh@pld-linux.org> 032b7ee
- pl

* Wed Oct 29 2014 Arkadiusz Miśkiewicz <arekm@maven.pl> 51f64c1
- rel 2; BR gettext-autopoint

* Mon Oct 27 2014 Elan Ruusamäe <glen@delfi.ee> ecb3403
- unify, make source0 url rpm5 safe

* Mon Oct 27 2014 Arkadiusz Miśkiewicz <arekm@maven.pl> 17484f0
- a bit more than raw (from fc)

